"use strict";var a=function(r,t){return function(){return t||r((t={exports:{}}).exports,t),t.exports}};var n=a(function(u,i){
var e=require('@stdlib/utils-native-class/dist'),s=typeof Uint8Array=="function";function o(r){return s&&r instanceof Uint8Array||e(r)==="[object Uint8Array]"}i.exports=o
});var y=n();module.exports=y;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
